.. triflow documentation master file, created by
   sphinx-quickstart on Thu Jan 26 14:29:11 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to triflow's documentation!
===================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   installation
   overview
   schemes
   cookbook/displays
   cookbook
   contribute
   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
